@@ -8,6 +8,8 @@
 #ifndef PACKAGETOOL_H
 #define PACKAGETOOL_H
 
+#include "package.h"
+#include "packagejob.h"
 #include <QCoreApplication>
 
 class QCommandLineParser;
@@ -23,19 +25,17 @@ class PackageTool : public QCoreApplication
 
 public:
     PackageTool(int &argc, char **argv, QCommandLineParser *parser);
-    virtual ~PackageTool();
+    ~PackageTool() override;
 
-    void listPackages(const QStringList &types, const QString &path = QString());
+    void listPackages(const QString &kpackageType, const QString &path = QString());
     void showPackageInfo(const QString &pluginName);
     void showAppstreamInfo(const QString &pluginName);
-    QString findPackageRoot(const QString &pluginName, const QString &prefix);
-    void recreateIndex();
-    void removeIndex();
+    QString resolvePackageRootWithOptions();
 
 private Q_SLOTS:
     void runMain();
-    void packageInstalled(KJob *job);
-    void packageUninstalled(KJob *job);
+    void packageInstalled(KPackage::PackageJob *job);
+    void packageUninstalled(KPackage::PackageJob *job);
 
 private:
     PackageToolPrivate *d;
